r"""
The Cell_BLAST package
"""

# from .utils import in_ipynb

# if not in_ipynb():
#     import matplotlib
#     matplotlib.use("agg")

# from . import (blast, config, data, directi, latent, metrics, prob, rmbatch,
#                utils)


name = "SC_search"

__copyright__ = "BME"

__author__ = "Cheng Zhang"

# __all__ = [
#     "blast",
#     "data",
#     "directi",
#     "latent",
#     "metrics",
#     "prob",
#     "rmbatch",
#     "utils",
#     "config"
# ]

__version__ = "0.0.1"